#
# spec file for package votca-csg
#
# Copyright (c) 2020-2021 SUSE LLC
# Copyright (c) 2013-2021 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           votca-csg
Version:        1.6.4
Release:        bp153.1.1
%define         uversion %{version}
%define         sover 6
Summary:        VOTCA coarse-graining engine
License:        Apache-2.0
Group:          Productivity/Scientific/Chemistry
URL:            http://www.votca.org
Source0:        https://github.com/votca/csg/archive/v%{uversion}.tar.gz#/%{name}-%{uversion}.tar.gz
Source1:        https://github.com/votca/csg-tutorials/archive/v%{uversion}.tar.gz#/%{name}-tutorials-%{uversion}.tar.gz
Source2:        https://github.com/votca/csg-manual/releases/download/v%{uversion}/votca-csg-manual-%{uversion}.pdf

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  cmake >= 2.8.4
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gromacs-devel
BuildRequires:  hdf5-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  pkg-config
 #for hdf5
BuildRequires:  python3-txt2tags
BuildRequires:  votca-tools-devel = %{version}
BuildRequires:  zlib-devel

#exact same version is needed
Requires:       %{name}-common = %{version}
Requires:       libvotca_csg%sover = %{version}
# The developer man page was wrongly shipped in the library package until votca 1.6
Conflicts:      libvotca_csg5

%description
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the Coarse Graining Engine of VOTCA.

%package -n libvotca_csg%sover
Summary:        Libraries for the VOTCA coarse graining engine
Group:          System/Libraries

%description -n libvotca_csg%sover
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains libraries for the Coarse Graining Engine of VOTCA.

%package devel
Summary:        Development headers and libraries for the VOTCA Coarse Graining Engine
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libvotca_csg%sover = %{version}
Requires:       votca-tools-devel = %{version}

%description devel
This package contains development headers and libraries for the VOTCA
Coarse Graining Engine.

%package common
Summary:        Architecture-independent data files for VOTCA CSG
Group:          Productivity/Scientific/Chemistry
BuildArch:      noarch
Requires:       /usr/bin/awk
Requires:       bash
Requires:       perl

%description common
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the architecture-independent data files for VOTCA CSG.

%package tutorials
Summary:        Tutorial documentation for VOTCA Coarse Graining Engine
Group:          Productivity/Scientific/Chemistry
BuildArch:      noarch
Requires:       /bin/bash

%description tutorials
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the tutorial documentation and sample data.

%package doc
Summary:        Manual for VOTCA Coarse Graining Engine
Group:          Documentation/Other
BuildArch:      noarch

%description doc
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the PDF manual.

%package bash
Summary:        Bash completion for votca
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
BuildArch:      noarch

%description bash
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++. Iterative
methods are implemented using bash + perl.

This package contains the bash completion support for votca-csg.

%prep
%setup -n csg-%{uversion} -q

FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/libcsg/version.cc
tar -xzf %{S:1}

%build
%{cmake} -DWITH_RC_FILES=OFF -DCMAKE_SKIP_RPATH:BOOL=OFF -DWITH_H5MD=ON -DWITH_GMX=ON -DENABLE_TESTING=ON -DREGRESSIONTEST_TOLERANCE="2.1e-5"
%cmake_build

%install
%cmake_install
sed -i '1s@env @@' %{buildroot}/%{_datadir}/votca/scripts/inverse/cma_processor.py 

# Move bash completion file to correct location
mkdir -p %{buildroot}%{_datadir}/bash_completion.d
cp %{buildroot}%{_datadir}/votca/rc/csg-completion.bash %{buildroot}%{_datadir}/bash_completion.d/votca

%define pkgdocdir %{_docdir}/%{name}
mkdir -p %{buildroot}%{pkgdocdir}
cp %{S:2} %{buildroot}%{pkgdocdir}

mkdir -p %{buildroot}%{pkgdocdir}/examples
cp -r csg-tutorials-%{uversion}/* %{buildroot}%{pkgdocdir}/examples
sed -i '1s@env @@' %{buildroot}%{pkgdocdir}/examples/LJ1-LJ2/imc/svd.py

%fdupes %{buildroot}%{_prefix}

#check
make -C build test CTEST_OUTPUT_ON_FAILURE=1 %{?testargs}

%post -n libvotca_csg%sover -p /sbin/ldconfig
%postun -n libvotca_csg%sover -p /sbin/ldconfig

%files
%doc CHANGELOG.md NOTICE README.md LICENSE
%{_bindir}/csg_*
%{_mandir}/man1/*
%{_mandir}/man7/*
%exclude %{pkgdocdir}/examples
%exclude %{pkgdocdir}/*.pdf

%files doc
%{pkgdocdir}/*.pdf

%files tutorials
%{pkgdocdir}/examples

%files common
%{_datadir}/votca

%files -n libvotca_csg%sover
%doc LICENSE
%{_libdir}/libvotca_csg.so.%{sover}

%files devel
%{_includedir}/votca/csg/
%{_libdir}/libvotca_csg.so
%{_libdir}/cmake/VOTCA_CSG

%files bash
%dir %{_datadir}/bash_completion.d
%{_datadir}/bash_completion.d/votca

%changelog
* Tue Jan 12 2021 Christoph Junghans <junghans@votca.org>
- Update to 1.6.4
  - fix exclusion creation in csg_boltzmann ([gh#votca/csg#624],
    [gh#votca/csg#625])
* Wed Dec  9 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6.3
  - fix test dependencies for parallel ctest ([gh#votca/csg#585])
  - fix trigger for gmx-2020 warning in run_gromacs.sh
    ([gh#votca/csg#591])
  - switch to ghcr.io for CI ([gh#votca/csg#595])
  - format code with clang-11 ([gh#votca/csg#605])
  - add gmx2021 builds to CI ([gh#votca/csg#607])
  - remove set-env call from CI ([gh#votca/csg#608])
  - use master .clang-format in format action ([gh#votca/csg#610])
  - strip windows line endings in readers ([gh#votca/csg#614])
* Sat Aug 22 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6.2
  - move CI to GitHub Actions ([gh#votca/csg#563],
    [gh#votca/csg#567], [gh#votca/csg#569])
  - add max scaling parameter to pressure correction
    ([gh#votca/csg#565])
  - fix test dependencies for parallel ctest ([gh#votca/csg#573])
  - fix multicomponent imc ([gh#votca/csg#579],
    [gh#votca/csg#581])
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Wed Aug 19 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Increase a little bit REGRESSIONTEST_TOLERANCE to make it pass
  on aarch64
* Mon Jun 22 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6.1
  - add support for cma-3 ([gh#votca/csg#158])
  - allow special characters in build directory
    ([gh#votca/csg#521])
  - fix CI on Ubuntu-20.04 ([gh#votca/csg#526])
  - drop support for gmx 2016 ([gh#votca/csg#529],
    [gh#votca/csg#547])
  - fix csg_reupdate and add tests ([gh#votca/csg#525])
  - fix detection of lmp and gmx in cmake ([gh#votca/csg#540])
  - add test for lammpsdata reader ([gh#votca/csg#544])
* Thu Jun 11 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Move the miscellaneous manpages from the library package to the
  main package. SLPP disallows non-versioned files in the
  shared-library package as it makes them non-parallel installable
  to newer versions. Additionally, the man page does not provide
  information of pure library users (it's a list of what tools form
  the csg tools).
- have the main package conflict with the old library package
  (libvotca_csg5) that contained the man page.
* Sat Apr 18 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6
  - enforce periodic boundaries for dihedrals ([gh#votca/csg#500])
  - add warning about dihedrals ([gh#votca/csg#500])
  - fix typo in option in potential_extrapolate
    ([gh#votca/csg#502])
  - update gmx tab. potential warning ([gh#votca/csg#504])
  - fix exit code with clean for potential_to_lammps.sh
    ([gh#votca/csg#506])
  - remove obsolete link to MKL from cmake ([gh#votca/csg#508])
  - fix build with Gromacs 2021 ([gh#votca/csg#510],
    [gh#votca/csg#511])
  - warn about too long interaction in csg_stat
    ([gh#votca/csg#512])
  - fix testing in postadd_plot.sh ([gh#votca/csg#515])
* Mon Feb 10 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6_rc2
  - fix inheritance bug in cmake files ([gh#votca/csg#466])
  - fix build on 32-bit archs ([gh#votca/csg#473])
  - fixed alignment problem in potential class
    ([gh#votca/csg#471])
  - fix h5md reader ([gh#votca/csg#478], [gh#votca/csg#481])
  - added more tests for gmx ([gh#votca/csg#489]) and gmx-2020
    support ([gh#votca/csg#488])
  - add support for txt2tags-3.4 ([gh#votca/csg#491])
  - fix cma seed for testing ([gh#votca/csg#494])
  - remove old doxygen target ([gh#votca/csg#498])
* Thu Dec  5 2019 Christoph Junghans <junghans@votca.org>
- Update to 1.6_rc1
  * Major CMake refactor
  * Improved file readers
  * Added more tests
  * Added csg_imc_solve, removing octave and python solvers
* Thu Nov 21 2019 Christoph Junghans <junghans@votca.org>
- Upgrade to 1.5.1
  * bug fixes for gcc-5
  * some bugfixes for the lammps reader
  * support dynamics box size in h5md
  * fix build on CentOs7
* Thu Oct  3 2019 Christoph Junghans <junghans@votca.org>
- Disabled some test on i585 (comparison fixed in upstream master)
* Thu Sep 12 2019 Christoph Junghans <junghans@votca.org>
- Disable some more test on i585
* Tue Apr  2 2019 Christoph Junghans <junghans@votca.org>
- fix build with boost-1.69
* Thu Jan 31 2019 Christoph Junghans <junghans@votca.org>
- Upgrade to 1.5
  * cmake: only run csg_dump test if bash was found
  * added REGRESSIONTEST_TOLERANCE cmake option
  * added bug fix for memory leak in bead class
  * added topology unit test
  * added support for 3 body distribution
  * allow usage of _ in gmx options
  * support espresso-4.0
  * added LAMMPS data topology reader
  * added LAMMPS dump writer
  * added support for gmx-2019
  * move from gsl to Eigen3
  * added support for running gmx in multidir mode
  * extended pdb reader to read CONECT section
  * reworked perl interface to fix #179
  * make most install locations configureable
  * allow to change pot extrapolation fct for LAMMPS
  * dropped support for gmx-5.1
  * added unit and regression tests
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Sun Sep  3 2017 junghans@votca.org
- Upgrade to 1.4.1
  * fix pkg-config files
  * fix build with gmx-2017
  * added CSG_MDRUN_OPTS to run_gromacs.sh
  * table_to_tab.pl: fix forces for LAMMPS
  * csg_inverse: warn users of bug #179
  * run_gromacs.sh: check nstxout-compressed
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Oct 31 2016 jengelh@inai.de
- Update descriptions.
* Sat Oct 29 2016 junghans@votca.org
- Upgrade to 1.4
  * added cibi tutorial and manual section
  * xmltopologyparser: tokenize on \n and \t as well (#195)
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Tue Sep 27 2016 junghans@votca.org
- Upgrade to 1.4_rc1
  * switch to c++-11
  * dihedral support in csg_fmatch
  * support for tabulated bond in >=gmx-5
  * added full featured XMLTopologyReader
  * added regularization for IMC
  * changed neighborlist from std::list to std::vector
  * added cibi method
  * lots of reader bug fixes
  * dropped support for gromacs-4 and clean up
  * dropped multi_g_rdf script
  * dropped thermforce iteration method
  * moved h5md reader to hdf5 without c++ api
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Sun Aug 21 2016 jengelh@inai.de
- RPM group update
* Fri Aug 19 2016 junghans@votca.org
- Upgrade to 1.3.1
  * fixed build with >=cmake-3.4
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Fri Jan 15 2016 junghans@votca.org
- Upgrade to 1.3
  * re-implemented csg_boltzmann --excl
  * added support for upcoming gromacs 2016
  * details see 1.3 section of:
    https://github.com/votca/csg/blob/master/CHANGELOG.md
    or included CHANGELOG.md file
* Thu Oct  8 2015 junghans@votca.org
- Upgrade to 1.3_rc1
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Mon Sep  8 2014 junghans@votca.org
- depend on gromacs-devel instead for pkgconfig(libgmx) as
  gromacs-5.0 comes with libgromacs instead of libgmx
* Fri Sep  5 2014 junghans@votca.org
- Update to 1.2.4
  - support for Gromacs 5.0
* Fri Dec  6 2013 junghans@votca.org
- clean up for inclusion in OpenSuse:Factory
* Thu Oct 31 2013 junghans@votca.org
- Upgrade to 1.2.3
* Sun Aug 28 2011 kkaempf@suse.com
- Upgrade to 1.2.1
  - fixed lib soname, adapt BuildRequires
  - csg_inverse: improve initial guess of the potential
  - csg_inverse: fixes for min!=0
  - table_extrapolate.pl: fixed flags and first point
  - fixed tf iteration for multiple components
  - fixed round-off error in grid search and csg_calc
  - csg_inverse: typo fixed and additional checks
- Version 1.2 (SuperDoris)
  - changed buildsystem to cmake
  - added thermforce iteration method
  - added csg_density
  - a lot of framework clean up
  - added type selector name:*
  - allow long and restart of simulations
- Version 1.1.2
  - fixed head of votca-csg manpage
  - csg_fmatch: added support for known forces (--trj-force option)
* Thu Mar  3 2011 kkaempf@novell.com
- Upgrade to 1.1.1
  - parallel analysis using threads, some tools have a '--nt'
    option (e.g. fast parallel rdf calculation using grid search)
  - new spline types in csg_resample (akima, linear)
  - csg_inverse has about 25 new xml options (post-processing,
    run control, ...)
  - the manual is included as pdf
  - boundary treatment is done internally, no need to run trjconv
    anymore
* Mon Dec  6 2010 kkaempf@novell.com
- Initial version 1.0.1
- Add tutorials as documentation to votca-csg
* Tue Nov 30 2010 junghans@votca.org
- Minor clean up
* Thu Nov 25 2010 jussilehtola@fedoraproject.org
- First release
